package cn.fw.dalaran.common.constants;

import java.lang.reflect.Field;
import java.util.HashSet;
import java.util.Set;
import java.util.function.Function;

/**
 * 缓存名称
 * <p>
 * create at 2019-01-13
 *
 * @author zhangjj
 */
public final class CacheName {
    /**
     * 路径认证
     */
    public static final String AUTH_URL = "auth:url";
    /**
     * 所有集团
     */
    public static final String ALL_GROUPS = "all:groups";
    /**
     * 集团品牌
     */
    public static final String GROUP_BRANDS = "group:brands";
    /**
     * 集团门店
     */
    public static final String GROUP_SHOPS = "group:shops";
    /**
     * 用户门店
     */
    public static final String USER_SHOPS = "user:shops";
    /**
     * 门店角色
     */
    public static final Function<String, String> SHOP_ROLE = role -> String.format("shop:role:%s", role);

    /**
     * 门店角色列表
     */
    public static final Function<String, String> SHOP_ROLES = role -> String.format("shop:roles:%s", role);

    /**
     * 门店角色
     */
    public static final Function<String, String> GROUP_ROLE = role -> String.format("group:role:%s", role);

    /**
     * crm 试乘试驾
     */
    public static final String CRM_TD = "crm:td";
    /**
     * cas 套餐卡
     */
    public static final String CAS_MAINTAIN = "cas:maintain";
    /**
     * cas 质保卡
     */
    public static final String CAS_WARRANTY = "cas:warranty";
    /**
     * 集团考试配置
     */
    public static final String EHR_EXAM = "ehr:exam";
    /**
     * 集团实操配置
     */
    public static final String EHR_AUTH = "ehr:auth";
    /**
     * 集团资格配置
     */
    public static final String EHR_CERTIFY = "ehr:certify";

    /**
     * 门店月初定岗数
     */
    public static final String EHR_MONTHRECRUIT_SHOP = "ehr:monthrecruit:{0}:{1}";

    /**
     * 门店人事角色
     */
    public static final String EHR_SHOP_HR = "ehr:shop:hr:{0}";

    /**
     * 集团所有门店人事角色
     */
    public static final String EHR_All_SHOP_HR = "ehr:shop:hr:{0}:{1}";

    /**
     * 岗位列表 - 岗位大类
     */
    public static final String EHR_POST_TYPE ="ehr:post:type:{0}";

    /**
     * 执行率集团比
     */
    public static final String OFFICE_TIME_PROPORTION = "office:time:proportion:{0}";

    /**
     * 执行效果集团比
     */
    public static final String OFFICE_EFFECT_PROPORTION = "office:effect:proportion:{0}";

    /**
     * 平均执行力集团比
     */
    public static final String OFFICE_AVG_PROPORTION = "office:avg:proportion:{0}";


    static {
        final Set<String> codeSet = new HashSet<>();
        final Field[] fields = CacheName.class.getFields();
        for (final Field field : fields) {
            String name = null;
            try {
                final Object obj = field.get(CacheName.class);
                if (obj instanceof String) {
                    name = (String) obj;
                }
            } catch (IllegalAccessException ignored) {
            }
            if (name != null) {
                if (codeSet.contains(name)) {
                    throw new IllegalArgumentException("缓存名称重复定义");
                }
                codeSet.add(name);
            }
        }
    }

    /**
     * private constructor
     */
    private CacheName() {
        throw new UnsupportedOperationException();
    }

}
