package cn.fw.dalaran.domain.vo;

import cn.fw.dalaran.domain.enums.PlatformEnum;
import lombok.Data;
import lombok.ToString;

import java.math.BigDecimal;
import java.math.RoundingMode;
import java.util.Date;
import java.util.Objects;

/**
 * @author kurisu
 * @date 2021-12-20 16:03
 * @description 短视频池
 */
@Data
@ToString
public class VideoPoolVO {
    /**
     * 视频id
     */
    private String videoId;
    /**
     * 播放地址
     */
    private String playUrl;
    /**
     * 平台类型
     */
    private Integer platform;
    /**
     * 视频标题
     */
    private String title;
    /**
     * 预览图
     */
    private String preview;
    /**
     * 观看人数
     */
    private Integer uv;
    /**
     * 完整观看人数
     */
    private Integer fullUv;
    /**
     * 点赞数
     */
    private Integer likeNum;
    /**
     * 分享数
     */
    private Integer shareNum;
    /**
     * 评论数
     */
    private Integer commentNum;
    /**
     * 新增粉丝数
     */
    private Integer newFanNum;
    /**
     * 时长（秒）
     */
    private Integer duration;
    /**
     * 话题
     */
    private String tags;
    /**
     * 发布时间
     */
    private Date publishTime;
    /**
     * 所属人员
     */
    private String userName;
    /**
     * 所属门店
     */
    private String shopName;
    /**
     * 账号
     */
    private String account;
    /**
     * 所属活动主题
     */
    private String theme;
    /**
     * 品牌
     */
    private String brandName;
    /**
     * 车系
     */
    private String seriesName;
    /**
     * 是否有效视频
     */
    private Integer valid;
    /**
     * 视频完播率
     */
    private BigDecimal fullPlayRate;

    /**
     * 重写get方法
     *
     * @return 是否为有效视频
     */
    public boolean getValid() {
        return this.valid > 0;
    }

    /**
     * 获取平台名称
     *
     * @return 平台名
     */
    public String getPlatformDesc() {
        PlatformEnum platformEnum = PlatformEnum.ofValue(platform);
        if (Objects.isNull(platformEnum)) {
            return "";
        }
        return platformEnum.getName();
    }

    /**
     * 获取完播率
     *
     * @return 完播率
     */
    public BigDecimal getFullPlayRate() {
        if (Objects.isNull(this.uv) || Objects.isNull(fullUv) || Objects.equals(BigDecimal.valueOf(this.uv).compareTo(BigDecimal.ZERO), 0))
            return BigDecimal.ZERO;
        return BigDecimal.valueOf(this.fullUv).divide(BigDecimal.valueOf(this.uv), 4, RoundingMode.HALF_UP);
    }
}
