package cn.fw.dalaran.rpc.oop.dto;


import cn.fw.oop.sdk.enums.BizTypeEnum;
import cn.fw.oop.sdk.result.ShopInfoVo;
import com.fasterxml.jackson.annotation.JsonIgnore;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

/**
 * 门店信息DTO
 * <p>
 * create at 2019-07-24
 *
 * @author zhangjj
 */
@Data
@Builder(toBuilder = true)
@NoArgsConstructor
@AllArgsConstructor
public class ShopDTO {
    /**
     * 门店id
     */
    private Long id;
    /**
     * 门店名称
     */
    private String name;
    /**
     * 门店简称
     */
    private String shortName;
    /**
     * 业态
     */
    private Integer bizType;
    /**
     * 集团id
     */
    private Long groupId;

    public static ShopDTO with(final ShopInfoVo info) {
        return new ShopDTO().toBuilder()
                .id(info.getId())
                .name(info.getShopName())
                .shortName(info.getShortName())
                .groupId(info.getGroupId())
                .bizType(info.getBizType())
                .build();
    }

    /**
     * 是否为新车销售门店
     */
    @JsonIgnore
    public boolean isSaleCar() {
        return BizTypeEnum.PRE_SALE.getValue().equals(bizType);
    }

    /**
     * 是否为售后门店
     */
    @JsonIgnore
    public boolean isAfterSale() {
        return BizTypeEnum.AFTER_SALE.getValue().equals(bizType);
    }

    /**
     * 是否为二手车门店
     */
    @JsonIgnore
    public boolean isUsedCar() {
        return BizTypeEnum.USED_CAR.getValue().equals(bizType);
    }

    /**
     * 是否为租车门店
     */
    @JsonIgnore
    public boolean isRentCar() {
        return BizTypeEnum.RENT_CAR.getValue().equals(bizType);
    }
}
